@@ -17,12 +17,13 @@
 
 #include "showedittextfileagent.h"
 
-#include <kdialogbase.h>
 #include <klocale.h>
+#include <kdialog.h>
 
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qfile.h>
+#include <QVBoxLayout>
 
 #include "../windows/rkcommandeditorwindow.h"
 #include "../rbackend/rinterface.h"
@@ -38,9 +39,26 @@ ShowEditTextFileAgent::ShowEditTextFileAgent (RCallbackArgs *args, const QString
 
 	ShowEditTextFileAgent::args = args;
 
-	dialog = new ShowEditTextFileDialog (text, caption);
+	dialog = new KDialog (0);
+
+	// dialog setup
+	dialog->setCaption (caption);
+	dialog->setButtons (KDialog::Ok);
+	dialog->setModal (false);
+
+	QWidget *page = new QWidget (dialog);
+	dialog->setMainWidget (page);
+	QVBoxLayout *layout = new QVBoxLayout (page);
+	layout->setContentsMargins (0, 0, 0, 0);
+	QLabel *label = new QLabel (text, page);
+	label->setWordWrap (true);
+	layout->addWidget (label);
+
+	dialog->setButtonText (KDialog::Ok, i18n ("Done"));
+
 	connect (dialog, SIGNAL (finished ()), this, SLOT (done ()));
 
+	// do it
 	dialog->show ();
 }
 
@@ -67,7 +85,7 @@ void ShowEditTextFileAgent::showEditFiles (RCallbackArgs *args) {
 		for (int n = 0; n < args->int_a; ++n) {
 			message.append (args->chars_a[n]).append (" (\"").append (args->chars_b[n]).append ("\")\n");
 
-			bool ok = RKWorkplace::mainWorkplace ()->openScriptEditor (KURL (args->chars_a[n]), false, true, QString (*(args->chars_c)));
+			bool ok = RKWorkplace::mainWorkplace ()->openScriptEditor (KUrl (args->chars_a[n]), false, true, QString (*(args->chars_c)));
 
 			if (!ok)  {
 				bad_files_list.append ("- ").append (args->chars_a[n]).append (" (\"").append (args->chars_b[n]).append ("\")\n");
@@ -80,7 +98,7 @@ void ShowEditTextFileAgent::showEditFiles (RCallbackArgs *args) {
 		for (int n = 0; n < args->int_a; ++n) {
 			message.append (args->chars_a[n]).append (" (\"").append (args->chars_b[n]).append ("\")\n");
 
-			bool ok = RKWorkplace::mainWorkplace ()->openScriptEditor (KURL (args->chars_a[n]), true, false, QString (args->chars_b[n]));
+			bool ok = RKWorkplace::mainWorkplace ()->openScriptEditor (KUrl (args->chars_a[n]), true, false, QString (args->chars_b[n]));
 
 			if (!ok) {
 				bad_files_list.append ("- ").append (args->chars_a[n]).append (" (\"").append (args->chars_b[n]).append ("\")\n");
@@ -99,17 +117,12 @@ void ShowEditTextFileAgent::showEditFiles (RCallbackArgs *args) {
 
 void ShowEditTextFileAgent::done () {
 	RK_TRACE (APP);
-	delete dialog;
+	dialog->deleteLater ();
 
 	// int_b in RShowFiles means files are to be deleted
 	if ((args->type == RCallbackArgs::RShowFiles) && args->int_b) {
 		for (int n = 0; n < args->int_a; ++n) {
-			// does not compile on some systems (October 2005).
-			//QFile (QString (args->chars_a[n])).remove ();
-			// Workaround (use this instead for a couple of months):
-			QFile file;
-			file.setName (QString (args->chars_a[n]));
-			file.remove ();
+			RK_ASSERT (QFile::remove (QString (args->chars_a[n])));
 		}
 	}
 
@@ -121,21 +134,4 @@ void ShowEditTextFileAgent::done () {
 	deleteLater ();
 }
 
-///################# END ShowEditTextFileAgent ##################
-///################# BEGIN ShowEditTextFileDialog #################
-
-ShowEditTextFileDialog::ShowEditTextFileDialog (const QString &text, const QString &caption) : KDialogBase ((QWidget*) 0, 0, false, caption, KDialogBase::Ok, KDialogBase::Ok) {
-	QWidget *page = new QWidget (this);
-	setMainWidget (page);
-	QVBoxLayout *layout = new QVBoxLayout (page, 0, spacingHint ());
-	QLabel *label = new QLabel (text, page);
-	label->setAlignment (Qt::WordBreak | Qt::AlignAuto | Qt::AlignVCenter | Qt::ExpandTabs);
-	layout->addWidget (label);
-
-	setButtonOK (KGuiItem (i18n ("Done")));
-}
-
-ShowEditTextFileDialog::~ShowEditTextFileDialog () {
-}
-
 #include "showedittextfileagent.moc"
