@@ -48,14 +48,14 @@ REnvironmentObject::~REnvironmentObject () {
 	RK_TRACE (OBJECTS);
 }
 
-QString REnvironmentObject::getFullName () {
+QString REnvironmentObject::getFullName () const {
 	RK_TRACE (OBJECTS);
 
 	if (type & ToplevelEnv) return ("as.environment (\"" + name + "\")");
 	return parent->makeChildName (name, type & Misplaced);
 }
 
-QString REnvironmentObject::makeChildName (const QString &short_child_name, bool misplaced) {
+QString REnvironmentObject::makeChildName (const QString &short_child_name, bool misplaced) const {
 	RK_TRACE (OBJECTS);
 
 	if (type & GlobalEnv) return (short_child_name);
@@ -68,7 +68,7 @@ QString REnvironmentObject::makeChildName (const QString &short_child_name, bool
 	return (name + '$' + short_child_name);
 }
 
-QString REnvironmentObject::makeChildBaseName (const QString &short_child_name) {
+QString REnvironmentObject::makeChildBaseName (const QString &short_child_name) const {
 	RK_TRACE (OBJECTS);
 
 	if (type & ToplevelEnv) {
@@ -88,7 +88,7 @@ void REnvironmentObject::updateFromR (RCommandChain *chain) {
 	RK_TRACE (OBJECTS);
 	if (type & PackageEnv) {
 		if (RKSettingsModuleObjectBrowser::isPackageBlacklisted (namespace_name)) {
-			KMessageBox::information (0, i18n ("The package '%1' (probably you just loaded it) is currently blacklisted for retrieving structure information. Practically this means, the objects in this package will not appear in the object browser, and there will be no object name completion or function argument hinting for objects in this package.\nPackages will typically be blacklisted, if they contain huge amount of data, that would take too long to load. To unlist the package, visit Settings->Configure RKWard->Workspace.").arg (namespace_name), i18n("Package blacklisted"), "packageblacklist" + namespace_name);
+			KMessageBox::information (0, i18n ("The package '%1' (probably you just loaded it) is currently blacklisted for retrieving structure information. Practically this means, the objects in this package will not appear in the object browser, and there will be no object name completion or function argument hinting for objects in this package.\nPackages will typically be blacklisted, if they contain huge amount of data, that would take too long to load. To unlist the package, visit Settings->Configure RKWard->Workspace.", namespace_name), i18n("Package blacklisted"), "packageblacklist" + namespace_name);
 			return;
 		}
 	}
@@ -132,23 +132,13 @@ void REnvironmentObject::renameChild (RObject *object, const QString &new_name)
 	}
 }
 
-void REnvironmentObject::removeChild (RObject *object, bool removed_in_workspace) {
-	RK_TRACE (OBJECTS);
-
-	if ((type & GlobalEnv) || removed_in_workspace) {
-		RContainerObject::removeChild (object, removed_in_workspace);
-	} else {
-		RK_ASSERT (false);
-	}
-}
-
-QString REnvironmentObject::renameChildCommand (RObject *object, const QString &new_name) {
+QString REnvironmentObject::renameChildCommand (RObject *object, const QString &new_name) const {
 	RK_TRACE (OBJECTS);
 
 	return (makeChildName (new_name) + " <- " + object->getFullName () + '\n' + removeChildCommand (object));
 }
 
-QString REnvironmentObject::removeChildCommand (RObject *object) {
+QString REnvironmentObject::removeChildCommand (RObject *object) const {
 	RK_TRACE (OBJECTS);
 
 	return ("remove (" + object->getFullName () + ')');
